# Visual Kopasu

Visko (Visual-kopasu) is a Web-based software suite for Computational Linguistic Analysis based on construction grammars and ontologies (HPSG, SBCG, xMRS, Wordnet, texttaglib).

## Install

To be updated for version 0.2.3
